@@ -100,10 +100,14 @@ def _assert_header_prefix(data):
         raise DecryptionException('Data passed to decrypt were not generated by simple-crypt (bad header).')
 
 def _assert_header_version(data):
-    if len(data) >= HEADER_LEN and data[:HEADER_LEN] not in HEADER:
-        raise DecryptionException('The data appear to be encrypted with a more recent version of simple-crypt (bad header). ' +
-        'Please update the library and try again.')
-    return HEADER.index(data[:HEADER_LEN])
+    if len(data) >= HEADER_LEN:
+        try:
+            return HEADER.index(data[:HEADER_LEN])
+        except:
+            raise DecryptionException('The data appear to be encrypted with a more recent version of simple-crypt (bad header). ' +
+                                      'Please update the library and try again.')
+    else:
+        raise DecryptionException('Missing header.')
 
 def _assert_hmac(key, hmac, hmac2):
     # https://www.isecpartners.com/news-events/news/2011/february/double-hmac-verification.aspx
